﻿/* 
    Copyright (c) 2012 Microsoft Corporation. All rights reserved.
    Use of this sample source code is subject to the terms of the Microsoft license 
    agreement under which you licensed this sample source code and is provided AS-IS.
    If you did not accept the terms of the license agreement, you are not authorized 
    to use this sample source code. For the terms of the license, please see the 
    license agreement between you and Microsoft.
  
    To see all Code Samples for Windows Phone, visit http://go.microsoft.com/fwlink/?LinkID=219604 
  
*/

using System;
using System.Collections.Generic;
using Microsoft.Phone.Controls;
using System.Windows.Controls;
using System.Windows;
using System.IO.IsolatedStorage;
using System.IO;
using System.Collections.ObjectModel;

namespace HelperFunctions
{
    public static class Utilities
    {
        // Saves the current list of memos to iso-storage
        public static void SaveCollectionToIsoStorage(string fileName, IList<string> collection)
        {
            if (collection.Count == 0)
            {
                IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication();
                isoStore.DeleteFile(fileName);
            }
            else
            {
                WriteCollectionToIsoStorage(fileName, collection);
            }
        }

        // Writes all entries in a collection to a file, one line at a time.
        public static void WriteCollectionToIsoStorage(string fileName, IList<string> outputLines)
        {
            if (outputLines.Count < 1) return;

            IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication();

            using (var isoFileStream
                = new IsolatedStorageFileStream(fileName, FileMode.OpenOrCreate | FileMode.Truncate, isoStore))
            {
                // Write the data
                using (var isoFileWriter = new StreamWriter(isoFileStream))
                {
                    for (int i = 0; i < outputLines.Count; i++)
                    {
                        isoFileWriter.WriteLine(outputLines[i]);
                    }
                }
                isoFileStream.Close();
            }
        }

        // Reads contents of file at 'fileName' one line at a time and puts them in collection 'textLines'
        public static void ReadLinesFromIsoStorageFile(string fileName, IList<string> textLines)
        {
            IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication();

            // Read text lines from specified file and put into the string collection
            if (isoStore != null && isoStore.FileExists(fileName))
            {
                using (StreamReader memoReader = new StreamReader(isoStore.OpenFile(fileName, FileMode.Open, FileAccess.Read)))
                {
                    textLines.Clear();

                    for (int index = 1; !memoReader.EndOfStream; index++)
                    {
                        textLines.Add(memoReader.ReadLine());
                    }
                    memoReader.Close();
                }
            }
        }

        // Appends one line of text to a file in iso-storage. It does not have acccess to a Dispatcher so be sure to call it on a UI thread as necessary.
        public static void WriteLineToIsoStorage(string fileName, string outputLine)
        {
            try
            {
                if (String.IsNullOrEmpty(outputLine)) return;

                IsolatedStorageFile isoStore = IsolatedStorageFile.GetUserStoreForApplication();

                using (var isoFileStream = new IsolatedStorageFileStream(fileName, FileMode.OpenOrCreate | FileMode.Append, isoStore))
                {
                    // Write the data
                    using (var isoFileWriter = new StreamWriter(isoFileStream))
                    {
                        isoFileWriter.WriteLine(outputLine);
                    }
                    isoFileStream.Close();
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Exception in WriteLineToIsoStorage: " + ex.Message);
            }
        }

        // Simple helper function to set TextBox text on the UI thread
        public static void SetTextBoxTextSafely(TextBox tBox, string text)
        {
            tBox.Dispatcher.BeginInvoke(delegate { tBox.Text = text; });
        }

        // Return a string list array of the positive integers "1" through limit.
        public static List<string> GetStringListOfPositiveIntegers(int limit)
        {

            List<string> stringList = new List<string>(limit < 0 ? 0 : limit);

            for (int i = 1; i <= limit; i++)
            {
                stringList.Add(i.ToString());
            }

            return stringList;
        }

    }
}


